@@ -21,8 +21,8 @@
 
 /** \file  Schema bindings generator.
  *
- * This program simply takes the items given in the binding lists in
- * window-bindings.h and scheme-bindings.h and turns them into a portion of
+ * This program simply takes the items given in the binding list in
+ * all-keybindings.h and turns them into a portion of
  * the GConf .schemas file.
  *
  * FIXME: also need to make 50-metacity-desktop-key.xml
@@ -48,21 +48,6 @@ char *about_keybindings, *about_reversible_keybindings;
 char *source_filename, *target_filename;
 FILE *source_file, *target_file;
 
-const char* window_string = \
-	"    <schema>\n" \
-	"      <key>/schemas/apps/metacity/%s_keybindings/%s%s</key>\n" \
-	"      <applyto>/apps/metacity/%s_keybindings/%s%s</applyto>\n" \
-	"      <owner>metacity</owner>\n" \
-	"      <type>string</type>\n" \
-	"      <default>%s</default>\n" \
-	"      <locale name=\"C\">\n" \
-	"         <short>%s</short>\n" \
-	"         <long>\n" \
-	"          %s  %s\n" \
-	"         </long>\n" \
-	"      </locale>\n" \
-	"    </schema>\n\n\n";
-
 static void
 single_stanza (gboolean is_window, const char *name,
                const char *default_value,
@@ -77,7 +62,7 @@ single_stanza (gboolean is_window, const char *name,
 
   escaped_description = g_markup_escape_text (description, -1);
   escaped_default_value = default_value==NULL? "disabled":
-        g_markup_escape_text (description, -1);
+        g_markup_escape_text (default_value, -1);
   
   fprintf (target_file, "    <schema>\n");
   fprintf (target_file, "      <key>/schemas/apps/metacity/%s_keybindings/%s</key>\n",
@@ -107,6 +92,11 @@ static void produce_bindings ();
 static void
 produce_bindings ()
 {
+  /* 10240 is ridiculous overkill; we're writing the input file and
+   * the lines are always 80 chars or less.
+   */
+  char buffer[10240];
+
   source_file = fopen(source_filename, "r");
 
   if (!source_file)
@@ -123,15 +113,8 @@ produce_bindings ()
         target_filename, strerror (errno));
     }
 
-  while (!feof (source_file))
+  while (fgets (buffer, sizeof (buffer), source_file))
     {
-      /* 10240 is ridiculous overkill; we're writing the input file and
-       * the lines are always 80 chars or less.
-       */
-      char buffer[10240];
-      
-      fgets (buffer, sizeof (buffer), source_file);
-      
       if (strstr (buffer, "<!-- GENERATED -->"))
          break;
          
@@ -147,19 +130,12 @@ produce_bindings ()
                stroke, \
                flags & BINDING_REVERSES, \
                description);
-#include "window-bindings.h"
-#include "screen-bindings.h"
+#include "all-keybindings.h"
 #undef keybind
     }
 
-  while (!feof (source_file))
-    {
-      char buffer[10240];
-      
-      fgets (buffer, sizeof (buffer), source_file);
-      
+  while (fgets (buffer, sizeof (buffer), source_file))
       fprintf (target_file, "%s", buffer);
-    }
 
   if (fclose (source_file)!=0)
       g_error ("Cannot close %s: %s\n",
