@@ -1086,7 +1086,7 @@ show_tip_now (MetaFrames *frames)
       tiptext = _("Maximize Window");
       break;
     case META_FRAME_CONTROL_UNMAXIMIZE:
-      tiptext = _("Unmaximize Window");
+      tiptext = _("Restore Window");
       break;
     case META_FRAME_CONTROL_SHADE:
       tiptext = _("Roll Up Window");
@@ -1388,6 +1388,7 @@ meta_frames_button_press_event (GtkWidget      *widget,
       event->button == 1 &&
       event->type == GDK_2BUTTON_PRESS)
     {
+      meta_core_end_grab_op (gdk_display, event->time);
       return meta_frame_double_click_event (frame, event);
     }
 
